$title Policy control file

*	#User input: This should read - $set case [case file name]
$set case 5_con_sel
$set data colombia1

*	Load data, read in sets and define parameters
$include "..\inputs\load.gms"
$include "..\inputs\sets.gms"
$include "..\inputs\parameters.gms"

* ====================================================================================================================
* 1.	Indicate the type of scenario (only one should be turned on)
* ====================================================================================================================
scenario("benchmark") = 0;
scenario("reference") = 0;
scenario("policy") = 1;

*	Load reference values (policy scenarios only)
$gdxin "..\inputs\refstore.gdx"
$load gdp_store refghg ffmult_store
gdpbase = gdp_store;
ffmult_ref(g) = ffmult_store(g);

$include "..\inputs\ref_inputs.gms"

* ====================================================================================================================
* 2.	Define policies - all policy flags should be turned off in benchmark replication and reference simulations
* ====================================================================================================================

*	Load the default policy files that turns off all policies 
$include "..\inputs\policies.gms"

*	Turn on desired policy flags (none in the benchmark and reference cases) 
*	Turn on desired policy flags (none in the benchmark and reference cases) 
*	Cap-and-trade policy covering GHG emissions from specified sectors
policy("fclim") = 1;
*	Include all sectors in the policy
policy("clim") = 181.365;

*	Include selected sectors in the policy
fssclim("enuc") = 1;
fssclim("ecoa") = 1;
fssclim("egas") = 1;
fssclim("ewin") = 1;
fssclim("esol") = 1;
fssclim("ehyd") = 1;
fssclim("eoil") = 1;
fssclim("eoth") = 1;
fssclim("oil") = 1;
fssclim("crp") = 1;
fssclim("nmm") = 1;
fssclim("i_s") = 1;
fssclim("nfm") = 1;

*	Partial ETS coverage to target a broader emissions reduction
policy("pets") = 1;
policy("pets")$(policy("fclim") eq 0) = 0;

*	Turn on flag for non-CO2 emissions
policy("fnco2") = yes;

* "Trend+Investment 2030" Scenario (MINEM, 2017) specifies that 62% of electricity will be from non-fossil sources

policy("res") = 0.87;
fres("ewin") = 1;
fres("esol") = 1;
fres("eoth") = 1;
fres("ehyd") = 1;
fres("enuc") = 1;


* ====================================================================================================================
*	Call the data construction file 
$include "..\inputs\gtap9data-one.gms"
*	Load elasticities
$include "..\inputs\elasticities.gms"
*	Call the file to read in information for private transportation	
$include "..\inputs\transport.gms"
*	Call the model file 
$include "..\inputs\model.gms"
*	Call file to store the reference values needed for policy scenarios
if(scenario("reference") eq 1,
$include "..\inputs\refstore.gms";
);
*	Store all output in a gdx file
execute_unload "..\results\%case%.gdx";
 	



