$title	GAMS Code to Read a GTAP 9 Dataset

$gdxin "..\inputs\%data%.gdx";

$if not set nd $set nd 7

scalar nd	Number of decimals /%nd%/;
abort$(nd<>round(nd)) "Number of decimals must be an integer";

parameters
	vfm(f,g,r)	Endowments - Firms' purchases at market prices,
	vdfm(i,g,r)	Intermediates - firms' domestic purchases at market prices,
	vifm(i,g,r)	Intermediates - firms' imports at market prices,
	vxmd(i,r,s)	Trade - bilateral exports at market prices,
	exports
	vst(i,r)	Trade - exports for international transportation
$if declared hs6	viws_hs6(i,hs6,r,s)	Bilateral trade at world prices (HS6 goods)
	vtwr(i,j,r,s)	Trade - Margins for international transportation at world prices;

$load vfm vdfm vifm vxmd vst vtwr 
$if declared hs6 $load viws_hs6 

if (nd>0,
	vfm(f,g,r) = vfm(f,g,r)$round(vfm(f,g,r),nd);
	vdfm(i,g,r) = vdfm(i,g,r)$round(vdfm(i,g,r),nd);
	vifm(i,g,r) = vifm(i,g,r)$round(vifm(i,g,r),nd);
	vxmd(i,r,s) = vxmd(i,r,s)$round(vxmd(i,r,s),nd);
	vst(i,r) = vst(i,r)$round(vst(i,r),nd);
	vtwr(i,j,r,s) = vtwr(i,j,r,s)$round(vtwr(i,j,r,s),nd);
$if declared hs6	viws_hs6(i,hs6,r,s) = viws_hs6(i,hs6,r,s)$round(viws_hs6(i,hs6,r,s),nd);
);

display vxmd;

parameter
	evt(i,r,r)	Volume of energy trade (mtoe),
	evd(i,g,r)	Domestic energy use (mtoe),
	evi(i,g,r)	Imported energy use (mtoe),
	eco2d(i,g,r)	CO2 emissions in domestic fuels - Mt CO2",
	eco2i(i,g,r)	CO2 emissions in foreign fuels - Mt CO2";

$loaddc evd evi evt eco2d eco2i
if (nd>0,
	evt(i,r,s)  = evt(i,r,s)$round(evt(i,r,s), nd);
	evd(i,g,r) = evd(i,g,r)$round(evd(i,g,r), nd);
	evi(i,g,r) = evi(i,g,r)$round(evi(i,g,r), nd);
	eco2d(i,g,r) = eco2d(i,g,r)$round(eco2d(i,g,r), nd);
	eco2i(i,g,r) = eco2i(i,g,r)$round(eco2i(i,g,r), nd);
);

parameter
	rto(g,r)	Output (or income) subsidy rates
	rtf(f,g,r)	Primary factor and commodity rates taxes 
	rtfd(i,g,r)	Firms domestic tax rates
	rtfi(i,g,r)	Firms' import tax rates
	rtxs(i,r,s)	Export subsidy rates
$if declared hs6	rtms_hs6(hs6,r,s)	Bilateral tariff rates
	rtms(i,r,s)	Import taxes rates;

$load rto rtf rtfd rtfi rtxs rtms 
$if declared hs6 $load rtms_hs6

if (nd>0,
	rto(g,r) = rto(g,r)$round(rto(g,r),nd);
	rtf(f,g,r) = rtf(f,g,r)$round(rtf(f,g,r),nd);
	rtfd(i,g,r) = rtfd(i,g,r)$round(rtfd(i,g,r),nd);
	rtfi(i,g,r) = rtfi(i,g,r)$round(rtfi(i,g,r),nd);
	rtxs(i,r,s) = rtxs(i,r,s)$round(rtxs(i,r,s),nd);
	rtms(i,r,s) = rtms(i,r,s)$round(rtms(i,r,s),nd);
$if declared hs6  rtms_hs6(hs6,r,s) = rtms_hs6(hs6,r,s)$round(rtms_hs6(hs6,r,s),nd);
);


parameter
	esubd(i)	Elasticity of substitution (M versus D),
	esubva(g)	Elasticity of substitution between factors
	esubm(i)	Intra-import elasticity of substitution,
	etrae(f)	Elasticity of transformation,
	eta(i,r)	Income elasticity of demand,
	epsilon(i,r)	Own-price elasticity of demand;

$load esubd esubva esubm etrae eta epsilon

*	Declare some intermediate arrays which are required to 
*	evaluate tax rates:

parameter	vdm(g,r)	Aggregate demand for domestic output,
		vom(g,r)	Total supply at market prices;

vdm(i,r) = sum(g, vdfm(i,g,r));
vom(i,r) = vdm(i,r) + sum(s, vxmd(i,r,s)) + vst(i,r);

parameter
	rtf0(f,g,r)	Primary factor and commodity rates taxes 
	rtfd0(i,g,r)	Firms domestic tax rates
	rtfi0(i,g,r)	Firms' import tax rates
	rtxs0(i,r,s)	Export subsidy rates
	rtms0(i,r,s)	Import taxes rates;

rtf0(f,g,r) = rtf(f,g,r);
rtfd0(i,g,r) = rtfd(i,g,r);
rtfi0(i,g,r) = rtfi(i,g,r);
rtxs0(i,r,s) = rtxs(i,r,s);
rtms0(i,r,s) = rtms(i,r,s);

parameter	pvxmd(i,s,r)	Import price (power of benchmark tariff)
		pvtwr(i,s,r)	Import price for transport services;

pvxmd(i,s,r) = (1+rtms0(i,s,r)) * (1-rtxs0(i,s,r));
pvtwr(i,s,r) = 1+rtms0(i,s,r);

parameter	
	vtw(j)		Aggregate international transportation services,
	vpm(r)		Aggregate private demand,
	vgm(r)		Aggregate public demand,
	vim(i,r)	Aggregate imports,
	evom(f,r)	Aggregate factor endowment at market prices,
	vb(*)		Current account balance;

vtw(j) = sum(r, vst(j,r));
vom("c",r) = sum(i, vdfm(i,"c",r)*(1+rtfd0(i,"c",r)) + vifm(i,"c",r)*(1+rtfi0(i,"c",r)))/(1-rto("c",r));
vom("g",r) = sum(i, vdfm(i,"g",r)*(1+rtfd0(i,"g",r)) + vifm(i,"g",r)*(1+rtfi0(i,"g",r)))/(1-rto("g",r));
vom("i",r) = sum(i, vdfm(i,"i",r)*(1+rtfd0(i,"i",r)) + vifm(i,"i",r)*(1+rtfi0(i,"i",r)))/(1-rto("i",r));

vdm("c",r) = vom("c",r);
vdm("g",r) = vom("g",r);
vim(i,r) =  sum(g, vifm(i,g,r));
evom(f,r) = sum(g, vfm(f,g,r));
vb(r) = vom("c",r) + vom("g",r) + vom("i",r) 
	- sum(f, evom(f,r))
	- sum(g,  vom(g,r)*rto(g,r))
	- sum(g,  sum(i, vdfm(i,g,r)*rtfd(i,g,r) + vifm(i,g,r)*rtfi(i,g,r)))
	- sum(g,  sum(f, vfm(f,g,r)*rtf(f,g,r)))
	- sum((i,s), rtms(i,s,r) *  (vxmd(i,s,r) * (1-rtxs(i,s,r)) + sum(j,vtwr(j,i,s,r))))
	+ sum((i,s), rtxs(i,r,s) * vxmd(i,r,s));

vb("chksum") = sum(r, vb(r));
display vb;

parameter       mprofit Zero profit for m,
                yprofit Zero profit for y;

mprofit(i,r) = vim(i,r) - sum(s, pvxmd(i,s,r)*vxmd(i,s,r)+sum(j, vtwr(j,i,s,r))*pvtwr(i,s,r));
mprofit(i,r) = round(mprofit(i,r),5);
display mprofit;

yprofit(g,r) = vom(g,r)*(1-rto(g,r))
	- sum(i, vdfm(i,g,r)*(1+rtfd0(i,g,r))
               + vifm(i,g,r)*(1+rtfi0(i,g,r))) 
        - sum(f, vfm(f,g,r)*(1+rtf0(f,g,r)));

yprofit(g,r) = round(yprofit(g,r),6)
display yprofit;

*	Generate values for the target region

parameters
	vfmz(f,g)	Endowments - Firms' purchases at market prices,
	vdfmz(i,g)	Intermediates - firms' domestic purchases at market prices,
	vifmz(i,g)	Intermediates - firms' imports at market prices,
	vxmdz(i)	Trade - bilateral exports at market prices,
	vmmdz(i)	Trade - bilateral imports including export subsidies,
	vmmtz(i)	Trade - value of imports including transportation costs
	vstz(i)		Trade - exports for international transportation
	vtwrz(i,j)	Trade - Margins for international transportation at world prices
	varmz(i,g)	Value of Armington aggregate of good i used in sector g
	eco2dz(i,g)	CO2 emissions in domestic fuels - Mt CO2
	eco2iz(i,g)	CO2 emissions in foreign fuels - Mt CO2
	evtz(i)		Volume of energy trade - imports (mtoe)
	evdz(g,g)	Domestic energy use (mtoe) - inputs of enegry commodity g used in g
	eviz(g,g)	Imported energy use (mtoe) - inputs of enegry commodity g used in g
	evaz(g,g)	Armington energy use (mtoe) - inputs of enegry commodity g used in g
	evazt(i)	Armington enegry use by electricity type aggregated across sectors (mtoe) 
	evdpz(g)	Domestic energy production by enegry type (mtoe) 
	rtoz(g)		Output (or income) subsidy rates
	rtfz(f,g)	Primary factor and commodity rates taxes 
	rtfdz(i,g)	Firms domestic tax rates
	rtfiz(i,g)	Firms' import tax rates
	rtxsz(i)	Export subsidy rates
	rtmsz(i)	Import taxes rates
	pvxmdz(i)	Export price including the export subsidy
	pvmmdz(i)	Import price including import tariff
	pvtwrz(i)	Import price for transport services
	vomz(*)		Total supply at marketprices
	vdmz(*)		Aggregate demand for domestic output
	vimz(i)		Aggregate imports
	vxz(i)		Total value of exports including export taxes or subsidies
	vx0z(g)		Value of exports net of export taxes or subsidies
	evomz(f)	Aggregate factor endowments at market prices
	vbz		Current account balance
	rtf0z(f,g)	Primary factor and commodity rates taxes 
	rtfd0z(i,g)	Firms domestic tax rates
	rtfi0z(i,g)	Firms' import tax rates
	rtxs0z(i)	Export subsidy rates
	rtms0z(i)	Import taxes rates
	mprofitz	Zero profit for imports
	yprofitz	Zero profit for output
	tradez		Trade balance - should equal the value of vb
	tsf(g)		Share of capital payments attributed to the technology specific factor
	vtsfz(g)	Value of the technology specific factor;

vfmz(f,g) = sum(r1,vfm(f,g,r1));
vdfmz(i,g) = sum(r1,vdfm(i,g,r1));
vifmz(i,g) = sum(r1,vifm(i,g,r1));
vxmdz(i) = sum((s,r1),vxmd(i,r1,s));

vmmdz(i) = sum((r1,s),vxmd(i,s,r1)*(1-rtxs(i,s,r1)));

vstz(i) = sum(r1,vst(i,r1));
*	Note that vstz records the quantity of transportation services exported
*	and vtwrz records the quantity imported associated with imports
vtwrz(i,j) = sum((r1,s),vtwr(i,j,s,r1));

tsf(g) = 0;
tsf(etsf) = 0.05;
vtsfz(g) = tsf(g)*vfmz("cap",g);
vfmz("cap",g) = (1-tsf(g))*vfmz("cap",g);

eco2dz(i,g) = sum(r1, eco2d(i,g,r1));
eco2iz(i,g) = sum(r1, eco2i(i,g,r1));

evtz(i) = sum((s,r1), evt(i,s,r1));
evdz(i,g) = sum(r1, evd(i,g,r1));
eviz(i,g) = sum(r1, evi(i,g,r1));
evaz(i,g) = evdz(i,g) + eviz(i,g);

rtoz(g)	= sum(r1, rto(g,r1));
rtfz(f,g) = sum(r1, rtf(f,g,r1));
rtfdz(i,g) = sum(r1, rtfd(i,g,r1));
rtfiz(i,g) = sum(r1, rtfi(i,g,r1));
rtxsz(i) = sum((r1,s), rtxs(i,r1,s));
rtmsz(i) = sum((s,r1), rtms(i,s,r1));

pvxmdz(i) = 1+rtxsz(i);
*	Note that export subsidies imposed by other countries are included in the value of imports
pvmmdz(i) = 1+rtmsz(i);
pvtwrz(i) = 1+rtmsz(i);

vomz("c") = sum(r1, vom("c",r1));
vomz("g") = sum(r1, vom("g",r1));
vomz("i") = sum(r1, vom("i",r1));
vomz(i) = sum(r1, vom(i,r1));

vdmz("c") = sum(r1, vdm("c",r1));
vdmz("g") = sum(r1, vdm("g",r1));
vdmz(i) = sum(r1, vdm(i,r1));

vmmtz(i) = vmmdz(i)+sum(j,vtwrz(j,i));

vimz(i) = sum(r1, vim(i,r1));
vxz(i) = vxmdz(i)*(1-rtxsz(i)) + vstz(i)*(1-rtxsz(i));
vx0z(i) = vxmdz(i) + vstz(i);
evomz(f) = sum(r1, evom(f,r1));
vbz = sum(r1, vb(r1));

evazt("ecoa") = sum(g,evaz("ecoa",g));
evazt("egas") = sum(g,evaz("egas",g));
evazt("eoil") = sum(g,evaz("eoil",g));
evazt("enuc") = sum(g,evaz("enuc",g));
evazt("ehyd") = sum(g,evaz("ehyd",g));
evazt("ewin") = sum(g,evaz("ewin",g));
evazt("esol") = sum(g,evaz("esol",g));
evazt("eoth") = sum(g,evaz("eoth",g));

evdpz(g)$(vomz(g)-vx0z(g)) = sum(gg,evdz(g,gg))*vomz(g)/(vomz(g)-vx0z(g));

rtf0z(f,g) = rtfz(f,g);
rtfd0z(i,g) = rtfdz(i,g);
rtfi0z(i,g) = rtfiz(i,g);
rtxs0z(i) = rtxsz(i);
rtms0z(i) = rtmsz(i);

varmz(i,g) = vdfmz(i,g)*(1+rtfd0z(i,g)) + vifmz(i,g)*(1+rtfi0z(i,g));

mprofitz(i) = vimz(i) - (vmmdz(i)+sum(j,vtwrz(j,i)))*pvmmdz(i);
mprofitz(i) = round(mprofitz(i),5);

*	Total value of imports (including transport services) minus total value of exports (including exports subsidies and transport services)
tradez = sum(i,vmmdz(i)) + sum((j,i),vtwrz(j,i)) - sum(i,vxmdz(i)*(1-rtxsz(i)) + vstz(i));

yprofitz(g) = vomz(g)*(1-rtoz(g))
	- sum(i, vdfmz(i,g)*(1+rtfd0z(i,g))
               + vifmz(i,g)*(1+rtfi0z(i,g))) 
        - sum(f, vfmz(f,g)*(1+rtf0z(f,g)))
	- vtsfz(g)*(1+rtf0z("cap",g));

yprofitz(g) = round(yprofitz(g),6)

*	Define parameters for mobile and sector specific factors
Parameter
	fshare(g,f)	Share of currently employed factor that is fixed in that sector
	vffmz(f,g)	Payments to sector specific factors
	vmfmz(f,g)	Payments to mobile factors
	evmfz(f)	Earnings from mobile factors
	evffmz(f,g)	Earnings from sector specific factors
	evtsfz(g)	Earnings from technology specific factors;

fshare(g,f) = 0.5;
fshare(g,"cap") = ((1-depre(g))**(tyear - 2011))/gdpmult;
fshare(g,"lab") = 0;
fshare(g,"res") = 1;
fshare(g,"lnd") = 1;

vffmz(f,g) = fshare(g,f)*vfmz(f,g);
vmfmz(f,g) = (1-fshare(g,f))*vfmz(f,g);
evtsfz(g) = vtsfz(g);

evmfz(f) = sum(g,vmfmz(f,g));	
evffmz(f,g) = vffmz(f,g);	

*	Create Armington aggregates 
parameter
        a0z(i)		Armington supply
        m0z(i)		Aggregate import supply
        d0z(i)		Aggregate domestic supply
	vapz(i,g)	Total value of purchases from domestic and imported sources
   	eco2az(i,g)	Total value of CO2 emissions from domestic and imported sources - Mt CO2
	t_dz(i)		Tax on domestic output
        t_mz(i)		Tax on imported output
	checka(*,g)	Armington aggregation check;

d0z(i) = sum(g,vdfmz(i,g));
m0z(i) = sum(g,vifmz(i,g));

t_dz(i)$d0z(i) = sum(g, vdfmz(i,g)*rtfd0z(i,g)) / d0z(i);
t_mz(i)$m0z(i) = sum(g, vifmz(i,g)*rtfi0z(i,g)) / m0z(i);

a0z(i) = d0z(i)*(1+t_dz(i)) + m0z(i)*(1+t_mz(i));

vapz(i,g) = vdfmz(i,g)*(1+rtfd0z(i,g)) + vifmz(i,g)*(1+rtfi0z(i,g));
varmz(i,g) = vdfmz(i,g)*(1+rtfd0z(i,g)) + vifmz(i,g)*(1+rtfi0z(i,g));

eco2az(i,g) = eco2dz(i,g) + eco2iz(i,g);	

*	Set emissions from crude oil equal to zero
eco2az("cru",g) = 0;

checka("d0",i) = d0z(i)*(1+t_dz(i)) - sum(g, (1+rtfd0z(i,g))*vdfmz(i,g));
checka("m0",i) = m0z(i)*(1+t_mz(i)) - sum(g, (1+rtfi0z(i,g))*vifmz(i,g));
checka("a0",i) = a0z(i) - sum(g, (1+rtfdz(i,g))*vdfmz(i,g)) - sum(g, (1+rtfiz(i,g))*vifmz(i,g));
checka("ae",i) = a0z(i) - sum(g,vapz(i,g));

*	Define and assign parameters to assist the specification of electricity production
Parameter 
	velea(*)	Aggregate Electricity and transmission and distribution use by sector
	vele_df		Total domestic fossil electricity - without transmission and distribution
	vele_dnf(i)     Domestic nonfossil electricity (without transmission and distribution
	vele_d		Total domestic electricity - without transmission and distribution
	vele_m		Total imported electricity (without transmission and distribution
	velez		Electricity aggregates;


velea(g) = sum(ele,varmz(ele,g)) + varmz("tnd",g);

velea("total") = sum(g,velea(g)); 

*	Total domestic fossil electricity (without transmission and distribution
vele_df = sum(i$efosi(i),d0z(i)*(1+t_dz(i)));
*	Total domestic nonfossil electricity (without transmission and distribution
vele_dnf(i) = d0z(i)*(1+t_dz(i));
*	Total domestic electricity (without transmission and distribution
vele_d = sum(i$ele(i),d0z(i)*(1+t_dz(i)));
*	Total imported electricity (without transmission and distribution
vele_m = sum(i$ele(i),m0z(i)*(1+t_mz(i)));
*	Total electricity (domestic and imports) with transmission and distribution
velez = sum(i$(ele(i) or tnd(i)),d0z(i)*(1+t_dz(i))+m0z(i)*(1+t_mz(i)));

checka("elec",g) = vomz(g)*(1-rtoz(g)) 
	- sum(i$(not ele(i) and not tnd(i)),varmz(i,g)) 
 	- velea(g) - vtsfz(g)
	- sum(f,(vffmz(f,g)+vmfmz(f,g))*(1+rtf0z(f,g)));

*	Calculate total CO2 emissions in the benchmark
ghgt("Benchmark") = sum((fe,g),eco2dz(fe,g)) + sum((fe,g),eco2iz(fe,g));
ghgs("Benchmark") = sum((fe,g),eco2dz(fe,g)$fssclim(g)) + sum((fe,g),eco2iz(fe,g)$fssclim(g));

*	Assign values for ffmult
ffmult(i)$scenario("benchmark")  = 1;
ffmult(i) = 1;
ffmult("col")$(scenario("benchmark") eq 0) = ffprice("col");
ffmult("cru")$(scenario("benchmark") eq 0) = ffprice("gas");
ffmult("gas")$(scenario("benchmark") eq 0) = ffprice("gas");

*	Assign value for gdpbase and ff_ref in non-policy scenarios
gdpbase$(scenario("policy") eq 0) = 1;
ffmult_ref(g)$(scenario("policy") eq 0) = 1;

eco2az(i,g) = eco2az(i,g)*co2scale(i,g);

*	Set emissoins equal to zero if there is no output
oghg(ghg,g)$(vomz(g) eq 0) = 0;


